==> kpprinter-0.0.3.tar.gz: ios/Classes/KPPrinterSeriesID.h <==
//
//  KPPrinterSeriesID.h
//  printerProje
//
//  Created by AmaniMacbook1 on 2019/10/16.
//  Copyright © 2019 AmaniMacbook1. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CoreBluetooth.h>
#import <CoreBluetooth/CBService.h>
#import "Print.h"
#import <Flutter/Flutter.h>


typedef void(^searchResult)(NSDictionary *aDicPrinter);
typedef void(^connectResult)(NSString *aStrResult);
typedef void(^disconnectResult)(NSString *aStrResult);
typedef void(^printResult)(NSString *aStrResult);
typedef void(^bluetoothIsOpenResult)(NSString *aStrResult);
typedef void(^connectAndPrintResult)(NSString *aStrResult);

NS_ASSUME_NONNULL_BEGIN

@interface KPPrinterSeriesID : NSObject <CBCentralManagerDelegate,CBPeripheralDelegate>

@property (strong ,nonatomic) searchResult searchResult_block;
@property (strong ,nonatomic) connectResult connectResult_block;
@property (strong ,nonatomic) disconnectResult disconnectResult_block;
@property (strong ,nonatomic) printResult printResult_block;
@property (strong ,nonatomic) bluetoothIsOpenResult bluetoothIsOpenResult_block;
@property (strong ,nonatomic) connectAndPrintResult connectAndPrintResult_block;

@property (strong ,nonatomic) FlutterEventSink eventSink_block;


@property dispatch_queue_t myQueue;

- (void)search:(NSString *)time;

- (void)connectPrinter:(NSDictionary *)aDic;

- (void)disconectPrinter:(NSDictionary *)aDic;

- (void)print:(NSArray *)aArr;

- (void)bluetoothIsOpen;

//串联方法（连接并打印）
- (void)connectAndPrint:(NSDictionary *)aDic;



@end

NS_ASSUME_NONNULL_END

==> kpprinter-0.0.16.tar.gz: ios/Classes/KPPrinterSeriesID.h <==
//
//  KPPrinterSeriesID.h
//  printerProje
//
//  Created by AmaniMacbook1 on 2019/10/16.
//  Copyright © 2019 AmaniMacbook1. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreBluetooth/CoreBluetooth.h>
#import <CoreBluetooth/CBService.h>
#import "Print.h"
#import <Flutter/Flutter.h>


typedef void(^searchResult)(NSString *aStrResult);
typedef void(^connectResult)(NSString *aStrResult);
typedef void(^disconnectResult)(NSString *aStrResult);
typedef void(^printResult)(NSString *aStrResult);
typedef void(^bluetoothIsOpenResult)(NSString *aStrResult);
typedef void(^connectAndPrintResult)(NSString *aStrResult);

NS_ASSUME_NONNULL_BEGIN

@interface KPPrinterSeriesID : NSObject <CBCentralManagerDelegate,CBPeripheralDelegate>

@property (strong ,nonatomic) searchResult searchResult_block;
@property (strong ,nonatomic) connectResult connectResult_block;
@property (strong ,nonatomic) disconnectResult disconnectResult_block;
@property (strong ,nonatomic) printResult printResult_block;
@property (strong ,nonatomic) bluetoothIsOpenResult bluetoothIsOpenResult_block;
@property (strong ,nonatomic) connectAndPrintResult connectAndPrintResult_block;

@property (strong ,nonatomic) FlutterEventSink eventSink_block;


@property dispatch_queue_t myQueue;

- (void)search:(NSString *)time;

- (void)connectPrinter:(NSDictionary *)aDic;

- (void)disconectPrinter:(NSDictionary *)aDic;

- (void)print:(NSArray *)aArr;

- (void)bluetoothIsOpen;

//串联方法（连接并打印）
- (void)connectAndPrint:(NSDictionary *)aDic;



@end

NS_ASSUME_NONNULL_END
